@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.34 2005/02/15 12:48:33 bdejean Exp $ */
+/* $Id: init.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/sysdeps.h>
+#include <glibtop/open.h>
 #include <glibtop/parameter.h>
+#include <glibtop/init_hooks.h>
 
 #ifndef DEFAULT_PORT
 #define DEFAULT_PORT 42800
@@ -218,7 +221,7 @@ glibtop *
 glibtop_init_s (glibtop **server_ptr, unsigned long features, unsigned flags)
 {
 	glibtop *server;
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server_ptr == NULL)
 		return NULL;
