@@ -1,4 +1,4 @@
-/* $Id: error.c,v 1.17.2.1 2004/12/22 18:12:52 bdejean Exp $ */
+/* $Id: error.c 2322 2005-03-25 13:24:14Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,11 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+
+#include <glib/gstrfuncs.h>
+#include <errno.h>
+
 #include <glibtop/error.h>
 
 #define DEFAULT_NAME	"LibGTop-Server"
@@ -30,17 +35,17 @@
 static void
 print_server_name (const glibtop *server)
 {
-	fprintf (stderr, "%s: ", server ?
-		 (server->name ? server->name : DEFAULT_NAME)
+	fprintf (stderr, "%s: ", server && server->name
+		 ? server->name
 		 : DEFAULT_NAME);
 }
 
 void
-glibtop_error_vr (glibtop *server, char *format, va_list args)
+glibtop_error_vr (glibtop *server, const char *format, va_list args)
 {
 	print_server_name (server);
 	vfprintf (stderr, format, args);
-	fprintf (stderr, "\n");
+	fputc('\n', stderr);
 
 #ifdef LIBGTOP_ENABLE_DEBUG
 	abort ();
@@ -50,11 +55,11 @@ glibtop_error_vr (glibtop *server, char *format, va_list args)
 }
 
 void
-glibtop_error_io_vr (glibtop *server, char *format, int error, va_list args)
+glibtop_error_io_vr (glibtop *server, const char *format, int error, va_list args)
 {
 	print_server_name (server);
 	vfprintf (stderr, format, args);
-	fprintf (stderr, ": %s\n", strerror (error));
+	fprintf (stderr, ": %s\n", g_strerror (error));
 
 #ifdef LIBGTOP_ENABLE_DEBUG
 	abort ();
@@ -64,11 +69,11 @@ glibtop_error_io_vr (glibtop *server, char *format, int error, va_list args)
 }
 
 void
-glibtop_warn_vr (glibtop *server, char *format, va_list args)
+glibtop_warn_vr (glibtop *server, const char *format, va_list args)
 {
 	print_server_name (server);
 	vfprintf (stderr, format, args);
-	fprintf (stderr, "\n");
+	fputc('\n', stderr);
 
 #ifdef LIBGTOP_FATAL_WARNINGS
 	abort ();
@@ -76,11 +81,11 @@ glibtop_warn_vr (glibtop *server, char *format, va_list args)
 }
 
 void
-glibtop_warn_io_vr (glibtop *server, char *format, int error, va_list args)
+glibtop_warn_io_vr (glibtop *server, const char *format, int error, va_list args)
 {
 	print_server_name (server);
 	vfprintf (stderr, format, args);
-	fprintf (stderr, ": %s\n", strerror (error));
+	fprintf (stderr, ": %s\n", g_strerror (error));
 
 #ifdef LIBGTOP_FATAL_WARNINGS
 	abort ();
@@ -88,8 +93,8 @@ glibtop_warn_io_vr (glibtop *server, char *format, int error, va_list args)
 }
 
 
-void G_GNUC_UNUSED
-glibtop_error_r (glibtop *server, char *format, ...)
+void
+glibtop_error_r (glibtop *server, const char *format, ...)
 {
 	va_list args;
 
@@ -99,8 +104,8 @@ glibtop_error_r (glibtop *server, char *format, ...)
 }
 
 
-void G_GNUC_UNUSED
-glibtop_warn_r (glibtop *server, char *format, ...)
+void
+glibtop_warn_r (glibtop *server, const char *format, ...)
 {
 	va_list args;
 
@@ -109,8 +114,8 @@ glibtop_warn_r (glibtop *server, char *format, ...)
 	va_end (args);
 }
 
-void G_GNUC_UNUSED
-glibtop_error_io_r (glibtop *server, char *format, ...)
+void
+glibtop_error_io_r (glibtop *server, const char *format, ...)
 {
 	va_list args;
 
@@ -119,8 +124,8 @@ glibtop_error_io_r (glibtop *server, char *format, ...)
 	va_end (args);
 }
 
-void G_GNUC_UNUSED
-glibtop_warn_io_r (glibtop *server, char *format, ...)
+void
+glibtop_warn_io_r (glibtop *server, const char *format, ...)
 {
 	va_list args;
 
@@ -129,10 +134,9 @@ glibtop_warn_io_r (glibtop *server, char *format, ...)
 	va_end (args);
 }
 
-#if !defined(__GNUC__) && (!defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901L)
 
 void
-glibtop_error (char *format, ...)
+glibtop_error (const char *format, ...)
 {
 	va_list args;
 	va_start (args, format);
@@ -141,7 +145,7 @@ glibtop_error (char *format, ...)
 }
 
 void
-glibtop_warn (char *format, ...)
+glibtop_warn (const char *format, ...)
 {
 	va_list args;
 	va_start (args, format);
@@ -150,7 +154,7 @@ glibtop_warn (char *format, ...)
 }
 
 void
-glibtop_error_io (char *format, ...)
+glibtop_error_io (const char *format, ...)
 {
 	va_list args;
 	va_start (args, format);
@@ -159,12 +163,10 @@ glibtop_error_io (char *format, ...)
 }
 
 void
-glibtop_warn_io (char *format, ...)
+glibtop_warn_io (const char *format, ...)
 {
 	va_list args;
 	va_start (args, format);
 	glibtop_warn_io_vr (glibtop_global_server, format, errno, args);
 	va_end (args);
 }
-
-#endif /* !defined(__GNUC__) && (!defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901L) */
