@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.24 2004/03/09 23:13:31 hadess Exp $ */
+/* $Id: procmap.c 2536 2006-11-27 19:22:45Z bdejean $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procmap.h>
@@ -40,14 +41,20 @@
 #else
 #include <vm/vm_object.h>
 #include <vm/vm_map.h>
-#if (__FreeBSD_version >= 400011)
+#if (__FreeBSD_version >= 400011) || defined(__FreeBSD_kernel__)
 #include <vm/vm.h>
 #else
 #include <vm/vm_prot.h>
 #endif
 #endif
 
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#define _KVM_VNODE
+#endif
 #include <sys/vnode.h>
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#undef _KVM_VNODE
+#endif
 #include <sys/mount.h>
 #include <ufs/ufs/quota.h>
 #include <ufs/ufs/inode.h>
@@ -102,9 +109,9 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 	struct vm_object object;
 #endif
 	glibtop_map_entry *maps;
-#if defined __FreeBSD__
+#if (defined __FreeBSD__) || defined(__FreeBSD_kernel__)
 	struct vnode vnode;
-#if __FreeBSD_version >= 500039
+#if (__FreeBSD_version < 500039) && !defined(__FreeBSD_kernel__)
 	struct inode inode;
 #endif
 #endif
@@ -112,27 +119,29 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 	int update = 0;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MAP), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
 	/* It does not work for the swapper task. */
 	if (pid == 0) return NULL;
-	
+
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count < 1))
+	if ((pinfo == NULL) || (count < 1)) {
 		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
+		return NULL;
+	}
 
 	/* Now we get the memory maps. */
 
 	if (kvm_read (server->machine.kd,
-#if defined(__FreeBSD__) && (__FreeBSD_version >= 500013)
+#if (defined(__FreeBSD__) && (__FreeBSD_version >= 500013)) || defined(__FreeBSD_kernel__)
 		      (unsigned long) pinfo [0].ki_vmspace,
 #else
 		      (unsigned long) pinfo [0].kp_proc.p_vmspace,
-#endif 
+#endif
 		      (char *) &vmspace, sizeof (vmspace)) != sizeof (vmspace))
 		glibtop_error_io_r (server, "kvm_read (vmspace)");
 
@@ -150,9 +159,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 	buf->total = buf->number * buf->size;
 
-	maps = g_malloc (buf->total);
-
-	memset (maps, 0, buf->total);
+	maps = g_malloc0(buf->total);
 
 	buf->flags = _glibtop_sysdeps_proc_map;
 
@@ -172,8 +179,8 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			update = 1;
 		}
 
-#ifdef __FreeBSD__
-#if __FreeBSD__ >= 4
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if (__FreeBSD__ >= 4) || defined(__FreeBSD_kernel__)
 		if (entry.eflags & (MAP_ENTRY_IS_SUB_MAP))
 			continue;
 #else
@@ -249,7 +256,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 #endif
 
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 		/* If the object is of type vnode, add its size */
 
 		if (object.type != OBJT_VNODE)
@@ -257,17 +264,19 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 		if (!object.handle)
 			continue;
-		
+
 		if (kvm_read (server->machine.kd,
 			      (unsigned long) object.handle,
 			      &vnode, sizeof (vnode)) != sizeof (vnode))
 			glibtop_error_io_r (server, "kvm_read (vnode)");
 
-#if defined(__FreeBSD__) && (__FreeBSD_version >= 500039)
+#if (defined(__FreeBSD__) && (__FreeBSD_version >= 500039)) || defined(__FreeBSD_kernel__)
                switch (vnode.v_type) {
                    case VREG:
+#if (__FreeBSD_version < 600006) && !defined(__FreeBSD_kernel__)
                        maps [i-1].inode = vnode.v_cachedid;
                        maps [i-1].device = vnode.v_cachedfs;
+#endif
                    default:
                    continue;
                }
@@ -280,13 +289,9 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			      &inode, sizeof (inode)) != sizeof (inode))
 			glibtop_error_io_r (server, "kvm_read (inode)");
 
-		if (kvm_read (server->machine.kd,
-			      (unsigned long) vnode.v_mount,
-			      &mount, sizeof (mount)) != sizeof (mount))
-			glibtop_error_io_r (server, "kvm_read (mount)");
-#endif
 		maps [i-1].inode  = inode.i_number;
 		maps [i-1].device = inode.i_dev;
+#endif
 #endif
 	} while (entry.next != first);
 
