@@ -1,4 +1,4 @@
-/* $Id: procopenfiles.c,v 1.7 2005/12/12 09:38:12 jamesh Exp $ */
+/* $Id: procopenfiles.c 2546 2007-01-14 18:09:56Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    Copyright (C) 2004 Nicolás Lichtmaier
@@ -58,7 +58,8 @@ static void
 parse_file(const char *filename, LineParser parser, GHashTable *dict)
 {
 	FILE *f;
-	char line[1024];
+	char *line = NULL;
+	size_t size = 0;
 
 	f = fopen(filename, "r");
 
@@ -67,15 +68,16 @@ parse_file(const char *filename, LineParser parser, GHashTable *dict)
 		return;
 	}
 
-	/* skip the first line */
-	if(!fgets(line, sizeof line, f)) goto eof;
 
-	while(fgets(line, sizeof line, f))
-	{
+	/* skip the first line */
+	if (getline(&line, &size, f) == -1)
+		goto eof;
+
+	while (getline(&line, &size, f) != -1)
 		parser(dict, line);
-	}
 
  eof:
+	free(line);
 	fclose(f);
 }
 
