@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.24 2005/07/05 23:05:20 bdejean Exp $ */
+/* $Id: uptime.c 2379 2005-07-23 00:01:11Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,7 +30,9 @@
 #include <time.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
+  (1UL << GLIBTOP_UPTIME_UPTIME) \
++ (1UL << GLIBTOP_UPTIME_IDLETIME) \
++ (1UL << GLIBTOP_UPTIME_BOOT_TIME);
 
 /* Init function. */
 
