@@ -1,4 +1,4 @@
-/* $Id: glibtop_suid.h,v 1.9 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: glibtop_suid.h 1862 2003-10-20 15:20:16Z hadess $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 
 #include <sys/table.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 static inline void glibtop_suid_enter (glibtop *server) {
 	setreuid (server->machine.uid, server->machine.euid);
@@ -45,6 +45,6 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
