@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.9 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: procstate.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,19 +21,18 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/procstate.h>
 
 #include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_proc_state =
-#if (LIBGTOP_VERSION_CODE >= 1001002) && defined(HAVE_PROCFS_H)
+#ifdef HAVE_PROCFS_H
 (1L << GLIBTOP_PROC_STATE_HAS_CPU) + (1L << GLIBTOP_PROC_STATE_PROCESSOR) +
 (1L << GLIBTOP_PROC_STATE_LAST_PROCESSOR) +
 #endif
-#if LIBGTOP_VERSION_CODE >= 1001002
 (1L << GLIBTOP_PROC_STATE_RUID) + (1L << GLIBTOP_PROC_STATE_RGID) +
-#endif
 (1L << GLIBTOP_PROC_STATE_CMD) + (1L << GLIBTOP_PROC_STATE_STATE) +
 (1L << GLIBTOP_PROC_STATE_UID) + (1L << GLIBTOP_PROC_STATE_GID);
 
@@ -63,60 +62,42 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 
 	buf->uid = psinfo.pr_euid;
 	buf->gid = psinfo.pr_egid;
-#if LIBGTOP_VERSION_CODE >= 1001002
 	buf->ruid = psinfo.pr_uid;
 	buf->rgid = psinfo.pr_gid;
-#endif
+
 #ifdef HAVE_PROCFS_H
 	switch(psinfo.pr_lwp.pr_state)
 #else
-        switch(psinfo.pr_state)
+	switch(psinfo.pr_state)
 #endif
 	{
-		case SONPROC: 
-#if (LIBGTOP_VERSION_CODE >= 1001002) && defined(HAVE_PROCFS_H)
+		case SONPROC:
+#ifdef HAVE_PROCFS_H
 			buf->has_cpu = 1;
 			buf->processor = psinfo.pr_lwp.pr_onpro;
+			/* FIXME: fallthrough ? */
 #endif
 		case SRUN:
-#if LIBGTOP_VERSION_CODE >= 1001002
 			buf->state = GLIBTOP_PROCESS_RUNNING;
-#else
-			buf->state = 'R';
-#endif
 			break;
 		case SZOMB:
-#if LIBGTOP_VERSION_CODE >= 1001002
 			buf->state = GLIBTOP_PROCESS_ZOMBIE;
-#else
-			buf->state = 'Z';
-#endif
 			break;
 		case SSLEEP:
-#if LIBGTOP_VERSION_CODE >= 1001002
 			buf->state = GLIBTOP_PROCESS_INTERRUPTIBLE;
-#else
-			buf->state = 'S';
-#endif
 			break;
 		case SSTOP:
-#if LIBGTOP_VERSION_CODE >= 1001002
 			buf->state = GLIBTOP_PROCESS_STOPPED;
-#else
-			buf->state = 'T';
-#endif
 			break;
 		case SIDL:
-#if LIBGTOP_VERSION_CODE >= 1001002
 			buf->state = GLIBTOP_PROCESS_UNINTERRUPTIBLE;
-#else
-			buf->state = 'D';
-#endif
+			break;
 	}
-#if (LIBGTOP_VERSION_CODE >= 1001002) && defined(HAVE_PROCFS_H)
+
+#ifdef HAVE_PROCFS_H
 	buf->last_processor = psinfo.pr_lwp.pr_onpro;
 #endif
-	strncpy (buf->cmd, psinfo.pr_fname, 39);
+	g_strlcpy (buf->cmd, psinfo.pr_fname, sizeof buf->cmd);
 
 	buf->flags = _glibtop_sysdeps_proc_state;
 }
