@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.11 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: shm_limits.c 2486 2006-06-24 17:16:53Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,28 +21,44 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/shm_limits.h>
 
 #include <kvm.h>
+#include <rctl.h>
 #include <sys/shm.h>
 
-static struct nlist nlst[] = { {"shminfo"}, {NULL} };
+static const struct nlist nlst[] = { {"glibtop_shm_limits"}, {NULL} };
+
+#if GLIBTOP_SOLARIS_RELEASE >=51000
+static const unsigned long _glibtop_sysdeps_shm_limits = 0;
+#else
+# if GLIBTOP_SOLARIS_RELEASE < 50900
+static const unsigned long _glibtop_sysdeps_shm_limits =
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN);
+
+# else
 static const unsigned long _glibtop_sysdeps_shm_limits =
 (1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
 (1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG);
+# endif
+#endif
 
 /* Init function. */
 
 void
 glibtop_init_shm_limits_p (glibtop *server)
 {
-   	kvm_t *kd = server->machine.kd;
+#if GLIBTOP_SOLARIS_RELEASE < 51000
 
-   	if(kd && !kvm_nlist(kd, nlst))
+	kvm_t * const kd = server->machine.kd;
+
+	if(kd && !kvm_nlist(kd, nlst))
 		server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 	else
 		server->sysdeps.shm_limits = 0;
+#endif
 }
 
 /* Provides information about sysv ipc limits. */
@@ -50,19 +66,44 @@ glibtop_init_shm_limits_p (glibtop *server)
 void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-   	kvm_t *kd = server->machine.kd;
-	struct shminfo sinfo;
+#if GLIBTOP_SOLARIS_RELEASE < 51000
+
+	kvm_t * const kd = server->machine.kd;
+        glibtop_shm_limits sinfo;
+
 
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
 	if(!(server->sysdeps.shm_limits))
-	   	return;
+		return;
+
 	if(kvm_read(kd, nlst[0].n_value, (void *)&sinfo,
-		    sizeof(struct shminfo)) != sizeof(struct shminfo))
-	        return;
-        buf->shmmax = sinfo.shmmax;
-	buf->shmmin = sinfo.shmmin;
+                    sizeof(glibtop_shm_limits)) != sizeof(glibtop_shm_limits))
+
+		return;
+
+	buf->shmmax = sinfo.shmmax;
 	buf->shmmni = sinfo.shmmni;
+#if GLIBTOP_SOLARIS_RELEASE < 50900
+	buf->shmmin = sinfo.shmmin;
 	buf->shmseg = sinfo.shmseg;
+# endif
+#endif
+#if GLIBTOP_SOLARIS_RELEASE >= 51000
+       rctlblk_t *rblk;
+       if ((rblk = malloc(rctlblk_size())) == NULL)
+               return;
+
+       if (getrctl("project.max-shm-memory", NULL, rblk, RCTL_FIRST) == -1)
+               return;
+       else
+              buf->shmmax = rctlblk_get_value(rblk);
+
+       if (getrctl("project.max-shm-ids", NULL, rblk, RCTL_FIRST) == -1)
+               return;
+       else
+               buf->shmmni = rctlblk_get_value(rblk);
+
+#endif
 	buf->flags = _glibtop_sysdeps_shm_limits;
 }
